@@ -1,47 +1,72 @@
-#
-# This file is part of Dist-Zilla-Plugin-WSDL
-#
-# This software is copyright (c) 2011 by GSI Commerce.
-#
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-#
-use 5.008_008;
-use strict;
-use warnings;
-use utf8;
-
 package Dist::Zilla::Plugin::WSDL;
 
-BEGIN {
-    $Dist::Zilla::Plugin::WSDL::VERSION = '0.205';
-}
-
 # ABSTRACT: WSDL to Perl classes when building your dist
 
+use Modern::Perl '2010';    ## no critic (Modules::ProhibitUseQuotedVersion)
+
+our $VERSION = '0.206';     # VERSION
+use utf8;
+
+#pod =for test_synopsis
+#pod BEGIN { die "SKIP: this is ini, not perl\n"; }
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod     [WSDL]
+#pod     uri = http://example.com/path/to/service.wsdl
+#pod     prefix = My::Dist::Remote::
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This L<Dist::Zilla|Dist::Zilla> plugin will create classes in your
+#pod distribution for interacting with a web service based on that service's
+#pod published WSDL file.  It uses L<SOAP::WSDL|SOAP::WSDL> and can optionally add
+#pod both a class prefix and a typemap.
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod =over
+#pod
+#pod =item L<Dist::Zilla|Dist::Zilla>
+#pod
+#pod =item L<SOAP::WSDL|SOAP::WSDL>
+#pod
+#pod =back
+#pod
+#pod =cut
+
 use autodie;
 use English '-no_match_vars';
 use File::Copy 'copy';
 use LWP::UserAgent;
 use Moose;
-use MooseX::Has::Sugar;
+use Moose::Meta::TypeConstraint;
+use MooseX::AttributeShortcuts;
 use MooseX::Types::Moose qw(ArrayRef Bool HashRef Str);
 use MooseX::Types::Perl 'ModuleName';
 use MooseX::Types::URI 'Uri';
 use Path::Class;
-use Regexp::DefaultFlags;
-## no critic (RequireDotMatchAnything,RequireExtendedFormatting)
-## no critic (RequireLineBoundaryMatching)
 use SOAP::WSDL::Expat::WSDLParser;
 use SOAP::WSDL::Factory::Generator;
 use Try::Tiny;
 use namespace::autoclean;
-with 'Dist::Zilla::Role::Tempdir';
-with 'Dist::Zilla::Role::BeforeBuild';
+with qw(
+    Dist::Zilla::Role::Tempdir
+    Dist::Zilla::Role::BeforeBuild
+);
 
-has uri => ( ro, required, coerce, isa => Uri );
+#pod =attr uri
+#pod
+#pod URI (sometimes spelled URL) pointing to the WSDL that will be used to generate
+#pod Perl classes.
+#pod
+#pod =cut
 
-has _definitions => ( ro, lazy_build, isa => 'SOAP::WSDL::Definitions' );
+has uri => ( is => 'ro', required => 1, coerce => 1, isa => Uri );
+
+has _definitions => ( is => 'lazy', isa => 'SOAP::WSDL::Definitions' );
 
 sub _build__definitions {    ## no critic (ProhibitUnusedPrivateSubroutines)
     my $self = shift;
@@ -57,41 +82,84 @@ sub _build__definitions {    ## no critic (ProhibitUnusedPrivateSubroutines)
     return $wsdl;
 }
 
-has _OUTPUT_PATH => ( ro, isa => Str, default => q{.} );
+has _OUTPUT_PATH => ( is => 'lazy', isa => Str, default => q{.} );
 
-has prefix => ( ro,
+#pod =attr prefix
+#pod
+#pod String used to prefix generated class names.  Default is "My", which will result
+#pod in classes under:
+#pod
+#pod =over
+#pod
+#pod =item C<MyAttributes::>
+#pod
+#pod =item C<MyElements::>
+#pod
+#pod =item C<MyInterfaces::>
+#pod
+#pod =item C<MyServer::>
+#pod
+#pod =item C<MyTypes::>
+#pod
+#pod =item C<MyTypemaps::>
+#pod
+#pod =back
+#pod
+#pod =cut
+
+has prefix => (
+    is      => 'ro',
     default => 'My',
     isa     => Moose::Meta::TypeConstraint->new(
         message =>
             sub {'must be valid class name, optionally ending in "::"'},
         constraint => sub {
-            $ARG =~ s/ :: \z//;
+            ## no critic (Modules::RequireExplicitInclusion)
+            $ARG =~ s/ :: \z//msx;
             ModuleName->check($ARG);
         },
     ),
 );
 
+#pod =attr typemap
+#pod
+#pod A list of SOAP types and the classes that should be mapped to them. Provided
+#pod because some WSDL files don't always define every type, especially fault
+#pod responses.  Listed as a series of C<< => >> delimited pairs.
+#pod
+#pod Example:
+#pod
+#pod     typemap = Fault/detail/FooException => MyTypes::FooException
+#pod     typemap = Fault/detail/BarException => MyTypes::BarException
+#pod
+#pod =for Pod::Coverage mvp_multivalue_args
+#pod
+#pod =cut
+
 sub mvp_multivalue_args { return 'typemap' }
 
-has _typemap_lines => ( ro,
-    isa => ArrayRef [Str],
+has _typemap_lines => (
+    is       => 'ro',
+    isa      => ArrayRef [Str],
     traits   => ['Array'],
     init_arg => 'typemap',
     handles  => { _typemap_array => 'elements' },
     default  => sub { [] },
 );
 
-has _typemap => ( ro, lazy,
-    isa => HashRef [ModuleName],
+has _typemap => (
+    is      => 'lazy',
+    isa     => HashRef [ModuleName],
     traits  => ['Hash'],
     handles => { _has__typemap => 'count' },
     default => sub {
-        return { map { split / \s* => \s* /, $ARG } $ARG[0]->_typemap_array };
+        return { map { split / \s* => \s* /msx, $ARG }
+                $ARG[0]->_typemap_array };
     },
 );
 
 has _generator =>
-    ( ro, lazy_build, isa => 'SOAP::WSDL::Generator::Template::XSD' );
+    ( is => 'lazy', isa => 'SOAP::WSDL::Generator::Template::XSD' );
 
 sub _build__generator {    ## no critic (ProhibitUnusedPrivateSubroutines)
     my $self = shift;
@@ -108,7 +176,7 @@ sub _build__generator {    ## no critic (ProhibitUnusedPrivateSubroutines)
         next if not $generator->can($method);
         $generator->$method( $self->prefix
                 . ucfirst($prefix)
-                . ( $prefix eq 'server' ? q{} : 's' ) );
+                . ( 'server' eq $prefix ? q{} : 's' ) );
     }
 
     my %attr_method
@@ -121,7 +189,21 @@ sub _build__generator {    ## no critic (ProhibitUnusedPrivateSubroutines)
     return $generator;
 }
 
-has generate_server => ( ro, isa => Bool, default => 0 );
+#pod =attr generate_server
+#pod
+#pod Boolean value on whether to generate CGI server code or just interface code.
+#pod Defaults to false.
+#pod
+#pod =cut
+
+has generate_server => ( is => 'lazy', isa => Bool, default => 0 );
+
+#pod =method before_build
+#pod
+#pod Instructs L<SOAP::WSDL|SOAP::WSDL> to generate Perl classes for the provided
+#pod WSDL and gathers them into the C<lib> directory of your distribution.
+#pod
+#pod =cut
 
 sub before_build {
     my $self = shift;
@@ -154,14 +236,17 @@ sub before_build {
 }
 
 __PACKAGE__->meta->make_immutable();
+no Moose;
 1;
 
 __END__
 
 =pod
 
+=encoding utf8
+
 =for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
-cpants kwalitee diff irc mailto metadata placeholders
+cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 NAME
 
@@ -169,7 +254,7 @@ Dist::Zilla::Plugin::WSDL - WSDL to Perl classes when building your dist
 
 =head1 VERSION
 
-version 0.205
+version 0.206
 
 =head1 SYNOPSIS
 
@@ -237,7 +322,7 @@ Defaults to false.
 Instructs L<SOAP::WSDL|SOAP::WSDL> to generate Perl classes for the provided
 WSDL and gathers them into the C<lib> directory of your distribution.
 
-=for Pod::Coverage mvp_multivalue_args
+=for test_synopsis BEGIN { die "SKIP: this is ini, not perl\n"; }
 
 =head1 SEE ALSO
 
@@ -249,6 +334,8 @@ WSDL and gathers them into the C<lib> directory of your distribution.
 
 =back
 
+=for Pod::Coverage mvp_multivalue_args
+
 =head1 SUPPORT
 
 =head2 Perldoc
@@ -276,7 +363,7 @@ L<http://search.cpan.org/dist/Dist-Zilla-Plugin-WSDL>
 
 AnnoCPAN
 
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/Dist-Zilla-Plugin-WSDL>
 
@@ -294,7 +381,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Dist-Zilla-Plugin-WSDL>
+L<http://cpants.cpanauthors.org/dist/Dist-Zilla-Plugin-WSDL>
 
 =item *
 
@@ -308,7 +395,7 @@ L<http://www.cpantesters.org/distro/D/Dist-Zilla-Plugin-WSDL>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-WSDL>
 
@@ -344,7 +431,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by GSI Commerce.
+This software is copyright (c) 2015 by GSI Commerce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
